/*
 * Copyright 2012-2013 eBay Software Foundation and ios-driver committers
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.uiautomation.ios.inspector.controllers;

import org.openqa.selenium.WebDriverException;
import org.uiautomation.ios.UIAModels.Session;
import org.uiautomation.ios.inspector.model.Cache;
import org.uiautomation.ios.inspector.views.RedirectView;
import org.uiautomation.ios.inspector.views.View;

import javax.servlet.http.HttpServletRequest;

public class RefreshController implements IDECommandController {

  private final Cache cache;

  public RefreshController(Cache cache) {
    this.cache = cache;
  }

  public boolean canHandle(String pathInfo) {
    return pathInfo.contains("refresh");
  }

  public View handle(HttpServletRequest req) {
    long start = System.currentTimeMillis();
    Session s = new Session(extractSession(req.getPathInfo()));
    cache.getModel(s).refresh();
    return new RedirectView("home");
  }

  private String extractSession(String pathInfo) {

    if (pathInfo.startsWith("/session/")) {
      String tmp = pathInfo.replace("/session/", "");
      if (tmp.contains("/")) {
        return tmp.split("/")[0];
      } else {
        return tmp;
      }
    } else {
      throw new WebDriverException("cannot extract session id from " + pathInfo);
    }
  }

}
