/*
 * Copyright 2012-2013 eBay Software Foundation and ios-driver committers
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.uiautomation.ios.server.servlet;

import org.json.JSONException;
import org.json.JSONObject;
import org.openqa.selenium.remote.BeanToJsonConverter;
import org.uiautomation.ios.IOSCapabilities;

import java.io.IOException;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class CapabilitiesServlet extends DriverBasedServlet {

  @Override
  protected void doGet(HttpServletRequest req, HttpServletResponse response) throws IOException {
    response.setCharacterEncoding("UTF-8");
    response.setContentType("text/html");
    response.setCharacterEncoding("UTF-8");
    response.setStatus(200);
    response.getWriter().write(page());
    response.getWriter().close();
  }


  private String page() {
    StringBuilder b = new StringBuilder();
    List<IOSCapabilities> caps = getDriver().getAllCapabilities();
    int i = 0;
    for (IOSCapabilities cap : caps) {
      String title = cap.getBundleId() + " on " + cap.getDevice();

      if (cap.isSimulator()) {
        title += "(Simulator)";
      }

      b.append("<h3>" + title + "</h3>");
      try {
        String json = new BeanToJsonConverter().convert(cap);
        JSONObject o = new JSONObject(json);
        b.append(o.toString(2));
      } catch (JSONException e) {
        e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
      }
      i++;
    }
    return b.toString();
  }

}
